@@ -195,6 +195,12 @@ void AI :: checkConquer( )
       ++nxt;
       pvehicle veh= getMap()->getUnit ( bi->second.unit );
       pbuilding bld = getMap()->getField( bi->first )->building;
+      if ( !bld ) {
+         buildingCapture.erase ( bi );
+         bi = nxt;
+         continue;
+      }
+
       if ( getdiplomaticstatus2( bld->color, getPlayerNum()*8 ) != cawar
            || !( veh && fieldAccessible ( getMap()->getField( bi->first ), veh ) == 2 )) {
 
@@ -300,7 +306,7 @@ void AI :: checkConquer( )
       
       veh->aiparam[getPlayerNum()]->setJob ( AiParameter::job_conquer );
       veh->aiparam[getPlayerNum()]->setTask ( AiParameter::tsk_move );
-      veh->aiparam[getPlayerNum()]->dest = bld->getEntry();
+      veh->aiparam[getPlayerNum()]->dest.setnum( bld->getEntry().x, bld->getEntry().y, -1 );
    }
 
    // execute capture orders
