@@ -4,7 +4,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-2003  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2005  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1650,8 +1650,14 @@ void Reinforcements :: execute( MapDisplayInterface* md )
    while ( cnt < objectNum ) {
       Type type = Type(stream.readInt());
       if ( type == ReinfVehicle ) {
+         try {
          Vehicle* veh = Vehicle::newFromStream( gamemap, stream, ++gamemap->unitnetworkid );
          FindUnitPlacementPos fupp( gamemap, veh );
+         } 
+         catch ( InvalidID err ) {
+            displaymessage( "Error executing event 'Reinforcements'\n" +  err.getMessage(), 1);
+            throw ShutDownMap();
+         }
       }
       if ( type == ReinfBuilding ) {
         Building* bld = Building::newFromStream ( gamemap, stream );
