@@ -950,6 +950,8 @@ void loadStartupMap ( const char *gameToLoad=NULL )
                loadmap( gameToLoad );
                if ( actmap->network )
                   setallnetworkpointers ( actmap->network );
+               actmap->startGame();
+
             } catch ( tfileerror ) {
                fatalError ( "%s is not a legal map. ", gameToLoad );
             }
@@ -1224,8 +1226,14 @@ void showCargoSummary()
       calcCargoSummary( fld->vehicle, summary );
 
       ASCString s;
+
+      map<ASCString, int> sorter;
+
       for ( Summary::iterator i = summary.begin(); i != summary.end(); ++i )
-         s += vehicleTypeRepository.getObject_byID( i->first )->name + ": " + strrr(i->second) + "\n";
+         sorter[vehicleTypeRepository.getObject_byID( i->first )->name] = i->second;
+
+      for ( map<ASCString, int>::iterator i = sorter.begin(); i != sorter.end(); ++i )
+         s += i->first + ": " + strrr(i->second) + "\n";
 
       tviewanytext vat ;
       vat.init ( "Cargo information", s.c_str(), 20, -1 , 450, 480 );
@@ -1777,6 +1785,7 @@ void mainloopgeneralmousecheck ( void )
 }
 
 
+
 void  mainloop ( void )
 {
    tkey ch;
@@ -1856,6 +1865,13 @@ void  mainloop ( void )
 
             case ct_f11: {
 
+               int counter  = 0;
+               for ( int i = 0; i < vehicleTypeRepository.getNum(); ++i )
+                  if ( vehicleTypeRepository.getObject_byPos(i)->movemalustyp == 0 ) {
+                     printf( "%s \n", vehicleTypeRepository.getObject_byPos(i)->name.c_str()  );
+                     ++counter;
+                  }
+               displaymessage("%d / %d", 1, counter, vehicleTypeRepository.getNum() );
                // delete getactfield()->vehicle->aiparam[1];
                // getactfield()->vehicle->aiparam[1] = NULL;
                // displaymap();
@@ -2137,8 +2153,7 @@ int gamethread ( void* data )
 
    abortgame = 0;
    gameStartupComplete = true;
-
-
+   
    displayLogMessage ( 5, "entering outer main loop.\n" );
    do {
       try {
@@ -2185,6 +2200,10 @@ int gamethread ( void* data )
          }
       } /* endtry */
       catch ( NoMapLoaded ) { } /* endcatch */
+      catch ( ShutDownMap ) { 
+         delete actmap;
+         actmap = NULL;
+      }
       catch ( LoadNextMap lnm ) {
          if ( actmap->campaign ) {
             startnextcampaignmap( lnm.id );
@@ -2266,7 +2285,7 @@ int main(int argc, char *argv[] )
    SDL_Init ( SDL_INIT_VIDEO );
    #endif
 
-      
+
    SDLmm::Surface* icon = NULL;
    try {
       tnfilestream iconl ( "icon_asc.gif", tnstream::reading );
